============
Getting help
============

If you're stuck with a problem, try checking the `Google Groups archive`_ to see if
someone has encountered it before.  If not, then try asking on the mailing list
django-oscar@googlegroups.com.  If it's a common question, then we'll write up
the solution as a recipe.


.. _`Google Groups archive`: https://groups.google.com/forum/?fromgroups#!forum/django-oscar

If you think you found a bug, please read
:doc:`Reporting bugs <contributing/bugs-and-features>` and report it
in the `GitHub issue tracker`_.

.. _`GitHub issue tracker`: https://github.com/django-oscar/django-oscar/issues

